@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9976 2017-05-16 06:31:28Z Lavender $
+# $Id: __init__.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
-# $Revision: 9976 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
+import logging
 
 from django.conf import settings
 
@@ -45,4 +46,16 @@ FIXTURES_DIR_PATH = os.path.abspath(
     os.path.join('.', 'fixtures'))
     
 IMAGES_DIR_PATH = os.path.abspath(
-    os.path.join('.', 'images'))
\ No newline at end of file
+    os.path.join('.', 'images'))
+
+def cerateLogger(name, fileHandlername):
+    logger = logging.getLogger(name)
+    logger.setLevel(logging.DEBUG)
+    handler = logging.StreamHandler()
+    handler.setFormatter(
+        logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
+    logger.addHandler(handler)
+    fileHander = logging.FileHandler(fileHandlername)
+    fileHander.setLevel(logging.WARNING)
+    logger.addHandler(fileHander)
+    return logger
\ No newline at end of file
