@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: assign_templates.py 9976 2017-05-16 06:31:28Z Lavender $
+# $Id: assign_templates.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,23 +12,19 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
-# $Revision: 9976 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
-import logging
 import shutil
 import random
 import math
 
 from django.core.management.base import BaseCommand, CommandError
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+from Zephyrus.boilerplate.management.commands import cerateLogger
+
+logger = cerateLogger(__name__, "AssignTemplates.log")
 
 DIR_TEMPLATES_NUMBER = 100
 CHOSE_NUMBER = 20
