@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate.py 9978 2017-05-20 15:24:37Z Lavender $
+# $Id: build_boilerplate.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
-# $Revision: 9978 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
 import sys
 import re
-import logging
 import hashlib
 import json
 
@@ -29,13 +28,9 @@ from django.template.loader import get_template
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "BuildBoilerplate.log")
 
 # inside
 TEXT_TAGS = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'button',]
