@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 9980 2017-05-21 12:37:33Z Lavender $
+# $Id: build_templates.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-21 20:37:33 +0800 (週日, 21 五月 2017) $
-# $Revision: 9980 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
 import sys
-import logging
 import shutil
 
 from django.core.management.base import BaseCommand, CommandError
@@ -25,13 +24,9 @@ from django.conf import settings
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, ROOT_DIR_PATH)
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "BuildTemplates.log")
 
 class Command(BaseCommand):
 
