@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_pages.py 10170 2017-08-13 03:49:37Z Lavender $
+# $Id: create_pages.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,10 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-13 11:49:37 +0800 (週日, 13 八月 2017) $
-# $Revision: 10170 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
-import logging
 import json
 
 from django.core.management.base import BaseCommand
@@ -27,13 +26,9 @@ from cms.models.titlemodels import Title
 
 from Zephyrus.boilerplate.management.commands import (
         TEMPLATES_DIR_PATH, ROOT_DIR_PATH)
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "CreatePages.log")
 
 class Command(BaseCommand):
 
@@ -52,28 +47,23 @@ class Command(BaseCommand):
 
             createPage = False
             rootPage = None
-            if 'index.html' in files:
-                createPage = True
-                rootPage = 'index.html'
-            elif "Index.html" in files:
-                createPage = True
-                rootPage = 'Index.html'
+            if 'index.html' in [f.lower() for f in files]:
+                for i, f in enumerate([f.lower() for f in files], 0):
+                    if f == 'index.html':
+                        createPage = True
+                        rootPage = files[i]
             else:
                 for f in files:
                     if f.endswith('.html'):
                         rootPage = f
                         createPage = True
-                        with open('CreatePage.log', 'a+') as log:
-                            log.write(
-                                ("'%s' template use '%s' as root page.\n") % 
-                                (slug, rootPage))
+                        logger.warn(
+                            ("'%s' template use '%s' as root page.") % 
+                            (slug, rootPage))
                         break
 
             if not createPage:
-                with open('CreatePage.log', 'a+') as log:
-                    log.write(
-                        "%s No templates to create pages.\n" % slug)
-                logger.error('No templates to create pages.')
+                logger.error("%s No templates to create pages." % slug)
                 break
 
             if createPage:
