@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10169 2017-08-13 03:48:13Z Lavender $
+# $Id: create_zip.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,10 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-13 11:48:13 +0800 (週日, 13 八月 2017) $
-# $Revision: 10169 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
-import logging
 import shutil
 import zipfile
 import json
@@ -28,16 +27,9 @@ from django.template.loader import get_template
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
     IMAGES_DIR_PATH, ROOT_DIR_PATH, FIXTURES_DIR_PATH)
-    
-FILE_DIR = os.path.abspath(os.path.join(
-    __file__, '..', '..', '..', 'templates', 'boilerplate'))
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "CreateZip.log")
 
 class Command(BaseCommand):
 
@@ -93,24 +85,15 @@ class Command(BaseCommand):
                 logger.info("Zip " + path)
                 zip.write(path)
                 
-        # with open(os.path.join(FILE_DIR, 'py', 'setup.py'), 'rb') as f:
-            # content = f.read()
-                
-        # with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
-            # f.write(content.encode('utf8'))
+        temp = get_template('boilerplate/py/setup.py')
+        content = temp.render()
+        with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
+            f.write(content.encode('utf8'))
             
-        # with open(os.path.join(FILE_DIR, 'txt', 'README.txt'), 'rb') as f:
-            # content = f.read()
-            
-        # with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
-            # f.write(content.encode('utf8'))
-            
-        shutil.copyfile(
-            os.path.join(FILE_DIR, 'py', 'setup.py'), 
-            os.path.join(ROOT_DIR_PATH, 'setup.py'))
-        shutil.copyfile(
-            os.path.join(FILE_DIR, 'txt', 'README.txt'), 
-            os.path.join(ROOT_DIR_PATH, 'README.txt'))
+        temp = get_template('boilerplate/txt/README.txt')
+        content = temp.render()
+        with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
+            f.write(content.encode('utf8'))
 
         zip.write('./README.txt')
         logger.info("Zip README.txt")
