@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 9979 2017-05-20 16:33:56Z Lavender $
+# $Id: fix_template.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,10 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
-# $Revision: 9979 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
-import logging
 import shutil
 import hashlib
 
@@ -25,13 +24,9 @@ from django.conf import settings
 from cms.templatetags.cms_tags import *
 
 from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "FixTemplate.log")
             
 class Command(BaseCommand):
     
