@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: get_template.py 9978 2017-05-20 15:24:37Z Lavender $
+# $Id: get_template.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,24 +12,19 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
-# $Revision: 9978 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
-import logging
 import shutil
 
 from django.core.management.base import BaseCommand, CommandError
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, IMAGES_DIR_PATH, ROOT_DIR_PATH)
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "GetTemplate.log")
 
 class Command(BaseCommand):
 
@@ -48,7 +43,7 @@ class Command(BaseCommand):
             shutil.rmtree(TEMPLATES_DIR_PATH)
             logger.info("Remove Temeplates folder.")
         except Exception as e:
-            logger.error("Temeplates folder is not exist.")
+            logger.info("Temeplates folder is not exist.")
             os.mkdir(TEMPLATES_DIR_PATH)
         else:
             os.mkdir(TEMPLATES_DIR_PATH)
@@ -58,7 +53,7 @@ class Command(BaseCommand):
             shutil.rmtree(STATIC_DIR_PATH)
             logger.info("Remove static folder.")
         except Exception as e:
-            logger.error("Static folder is not exist.")
+            logger.info("Static folder is not exist.")
             os.mkdir(STATIC_DIR_PATH)
         else:
             os.mkdir(STATIC_DIR_PATH)
@@ -68,7 +63,7 @@ class Command(BaseCommand):
             shutil.rmtree(IMAGES_DIR_PATH)
             logger.info("Remove images folder.")
         except Exception as e:
-            logger.error("Images folder is not exist.")
+            logger.info("Images folder is not exist.")
             
 
         logger.info("-----Start copy templates-----")
@@ -91,10 +86,9 @@ class Command(BaseCommand):
                 for f in files:
                     if f.endswith('.html'):
                         copyHtml = True
-                        with open('GetTemplate.log', 'a+') as log:
-                            log.write(
-                                ("'%s' not have 'index.html', but have %s\n") % 
-                                (path, f))
+                        logger.warn(
+                            ("'%s' not have 'index.html', but have %s") % 
+                            (path, f))
             
 
             if copyHtml:
@@ -116,8 +110,6 @@ class Command(BaseCommand):
                     logger.info('Copy %s to static folder.' % dirName)
                 break
         if not copyHtml:
-            with open('GetTemplate.log', 'a+') as log:
-                log.write(
-                    ("'%s' not have html file\n") % path)
+            logger.error("'%s' not have html file" % path)
 
         logger.info('-----All OK!-----')
\ No newline at end of file
