@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 9986 2017-05-22 14:40:02Z Lavender $
+# $Id: pluginize.py 10200 2017-08-20 02:49:07Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-22 22:40:02 +0800 (週一, 22 五月 2017) $
-# $Revision: 9986 $
+# $Date: 2017-08-20 10:49:07 +0800 (週日, 20 八月 2017) $
+# $Revision: 10200 $
 
 import os
 import json
@@ -21,7 +21,7 @@ import logging
 import shutil
 import hashlib
 
-from django.core.management.base import BaseCommand
+from django.core.management.base import BaseCommand, CommandError
 from django.core.management import call_command
 from django.test.client import RequestFactory
 from django.db import transaction
@@ -37,13 +37,9 @@ from lxml.html import fromstring
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, FIXTURES_DIR_PATH, ROOT_DIR_PATH)
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
+logger = cerateLogger(__name__, "Pluginize.log")
 
 jsPath = os.path.join(STATIC_DIR_PATH, 'js', 'FixTemplate.js')
 
@@ -179,7 +175,7 @@ class Command(BaseCommand):
         #register.tag(Placeholder2)
         
         path = TEMPLATES_DIR_PATH
-        logger.error('Processing...')
+        logger.info('Processing...')
 
         if not os.path.exists(os.path.join(STATIC_DIR_PATH, 'js')):
             os.mkdir(os.path.join(STATIC_DIR_PATH, 'js'))
@@ -244,6 +240,9 @@ class Command(BaseCommand):
         
             if 'complexity' in data:
                 logger.info('Complexity : %d' % data['complexity'])
+            else:
+                logger.error('%s Complexity = 0' % data['slug'])
+                raise CommandError('%s Complexity = 0' % data['slug'])
             if 'upc' in data:
                 logger.info('UPC : %s' % data['upc'])
         
